import React, { useEffect } from 'react';
import { Routes, Route } from 'react-router-dom';
import { AuthProvider } from './contexts/AuthContext';
import { ProfileActionsProvider } from './contexts/ProfileActionsContext';
import { ClickSparkProvider, useClickSpark } from './contexts/ClickSparkContext';
import ClickSpark from './components/reactbits/Animations/ClickSpark/ClickSpark';
import AuthRoute from './components/auth/AuthRoute';
import GuestRoute from './components/auth/GuestRoute';
import Header from './components/layout/Header';
import Footer from './components/layout/Footer';
import HomePage from './pages/HomePage';
import CatalogPage from './pages/CatalogPage';
import MediaOverviewPage from './pages/MediaOverviewPage';
import ProfilePage from './pages/ProfilePage';
import RatingPage from './pages/RatingPage';
import AdminLayout from './components/admin/AdminLayout';
import AdminDashboard from './pages/admin/AdminDashboard';
import AdminMediaPage from './pages/admin/AdminMediaPage';
import AdminUsersPage from './pages/admin/AdminUsersPage';
import AdminSeasonsPage from './pages/admin/AdminSeasonsPage';
import AdminAchievementsPage from './pages/admin/AdminAchievementsPage';
import AdminSupportPage from './pages/admin/AdminSupportPage';
import NotFoundPage from './pages/NotFoundPage';
import LoginPage from './pages/LoginPage';
import RegisterPage from './pages/RegisterPage';
import ForgotPasswordPage from './pages/ForgotPasswordPage';
import SupportTicketForm from './components/support/SupportTicketForm';
import PrivacyPolicyPage from './pages/legal/PrivacyPolicyPage';
import TermsOfServicePage from './pages/legal/TermsOfServicePage';
import UserAgreementPage from './pages/legal/UserAgreementPage';
import ProfileSettingsPage from './pages/ProfileSettingsPage';
import AdminSuggestionsPage from './pages/admin/AdminSuggestionsPage';
import AdminRoute from './components/auth/AdminRoute';
import SupportPage from './pages/SupportPage';
import './index.css';

const AppContent = () => {
  const { addSpark } = useClickSpark();

  useEffect(() => {
    const handleClick = (e) => {
      console.log('[ClickSpark] Добавление искры:', e.clientX, e.clientY);
      addSpark(e.clientX, e.clientY);
    };

    document.addEventListener('click', handleClick);
    return () => document.removeEventListener('click', handleClick);
  }, [addSpark]);

  return (
        <div className="flex flex-col min-h-screen bg-campfire-dark text-campfire-light">
      <ClickSpark
        sparkColor="#FFA500"
        sparkSize={10}
        sparkRadius={15}
        sparkCount={8}
        duration={400}
        easing="cubic-bezier(0.4, 0, 0.2, 1)"
        extraScale={1.0}
      />
          <Header />
      <main className="flex-grow pt-16 pb-32">
            <Routes>
              <Route path="/" element={<HomePage />} />
              <Route path="/catalog" element={<CatalogPage />} />
              <Route path="/media/:path" element={<MediaOverviewPage />} />
              <Route path="/rating" element={<RatingPage />} />
          <Route path="/forgot-password" element={<ForgotPasswordPage />} />

          <Route path="/profile" element={<AuthRoute><ProfilePage /></AuthRoute>} />
          <Route path="/profile/:username" element={<ProfilePage />} />
          <Route path="/settings" element={<AuthRoute><ProfileSettingsPage /></AuthRoute>} />

          <Route path="/auth" element={<GuestRoute />}>
            <Route path="login" element={<LoginPage />} />
            <Route path="register" element={<RegisterPage />} />
              </Route>

          <Route path="/admin" element={<AdminRoute />}>
                <Route element={<AdminLayout />}>
                  <Route index element={<AdminDashboard />} />
                  <Route path="media" element={<AdminMediaPage />} />
                  <Route path="media/:mediaId/seasons" element={<AdminSeasonsPage />} />
              <Route path="users" element={<AdminUsersPage />} />
              <Route path="seasons" element={<AdminSeasonsPage />} />
                  <Route path="achievements" element={<AdminAchievementsPage />} />
              <Route path="support" element={<AdminSupportPage />} />
              <Route path="suggestions" element={<AdminSuggestionsPage />} />
                </Route>
              </Route>

          <Route path="/support" element={<AuthRoute />}>
            <Route index element={<SupportPage />} />
          </Route>

          <Route path="/privacy-policy" element={<PrivacyPolicyPage />} />
          <Route path="/terms-of-service" element={<TermsOfServicePage />} />
          <Route path="/user-agreement" element={<UserAgreementPage />} />

              <Route path="*" element={<NotFoundPage />} />
            </Routes>
          </main>
          <Footer />
        </div>
  );
};

function App() {
  return (
    <AuthProvider>
      <ProfileActionsProvider>
        <ClickSparkProvider>
          <AppContent />
        </ClickSparkProvider>
      </ProfileActionsProvider>
    </AuthProvider>
  );
}

export default App;
